@@ -12,6 +12,7 @@ import time
 from bitstring import BitArray
 
 import esptool
+from esptool.logger import log
 
 import reedsolo
 
@@ -55,9 +56,6 @@ class EspEfuses(base_fields.EspEfusesBase):
     Wrapper object to manage the efuse fields in a connected ESP bootloader
     """
 
-    debug = False
-    do_not_confirm = False
-
     def __init__(
         self,
         esp,
@@ -66,14 +64,12 @@ class EspEfuses(base_fields.EspEfusesBase):
         do_not_confirm=False,
         extend_efuse_table=None,
     ):
+        super().__init__(esp, skip_connect, debug, do_not_confirm, extend_efuse_table)
         self.Blocks = EfuseDefineBlocks()
         self.Fields = EfuseDefineFields(extend_efuse_table)
         self.REGS = EfuseDefineRegisters
         self.BURN_BLOCK_DATA_NAMES = self.Blocks.get_burn_block_data_names()
         self.BLOCKS_FOR_KEYS = self.Blocks.get_blocks_for_keys()
-        self._esp = esp
-        self.debug = debug
-        self.do_not_confirm = do_not_confirm
         if esp.CHIP_NAME != "ESP32-C3":
             raise esptool.FatalError(
                 "Expected the 'esp' param for ESP32-C3 chip but got for '%s'."
@@ -102,7 +98,7 @@ class EspEfuses(base_fields.EspEfusesBase):
                 for efuse in self.Fields.BLOCK2_CALIBRATION_EFUSES
             ]
         else:
-            if self["BLK_VERSION_MAJOR"].get() == 1:
+            if self.get_block_version() >= 100:
                 self.efuses += [
                     EfuseField.convert(self, efuse)
                     for efuse in self.Fields.BLOCK2_CALIBRATION_EFUSES
@@ -136,14 +132,14 @@ class EspEfuses(base_fields.EspEfusesBase):
         self.coding_scheme = self.REGS.CODING_SCHEME_RS
 
     def print_status_regs(self):
-        print("")
+        log.print("")
         self.blocks[0].print_block(self.blocks[0].err_bitarray, "err__regs", debug=True)
-        print(
+        log.print(
             "{:27} 0x{:08x}".format(
                 "EFUSE_RD_RS_ERR0_REG", self.read_reg(self.REGS.EFUSE_RD_RS_ERR0_REG)
             )
         )
-        print(
+        log.print(
             "{:27} 0x{:08x}".format(
                 "EFUSE_RD_RS_ERR1_REG", self.read_reg(self.REGS.EFUSE_RD_RS_ERR1_REG)
             )
@@ -176,7 +172,7 @@ class EspEfuses(base_fields.EspEfusesBase):
                     # For PGM_CMD it is not necessary.
                     return
         raise esptool.FatalError(
-            "Timed out waiting for Efuse controller command to complete"
+            "Timed out waiting for eFuse controller command to complete."
         )
 
     def efuse_program(self, block):
@@ -204,30 +200,30 @@ class EspEfuses(base_fields.EspEfusesBase):
             try:
                 self._esp = self.reconnect_chip(self._esp)
             except esptool.FatalError:
-                print("Can not re-connect to the chip")
+                log.print("Can not re-connect to the chip.")
                 if not self["DIS_DOWNLOAD_MODE"].get() and self[
                     "DIS_DOWNLOAD_MODE"
                 ].get(from_read=False):
-                    print(
+                    log.print(
                         "This is the correct behavior as we are actually burning "
-                        "DIS_DOWNLOAD_MODE which disables the connection to the chip"
+                        "DIS_DOWNLOAD_MODE which disables the connection to the chip."
                     )
-                    print("DIS_DOWNLOAD_MODE is enabled")
-                    print("Successful")
+                    log.print("DIS_DOWNLOAD_MODE is enabled.")
+                    log.print("Successful.")
                     sys.exit(0)  # finish without errors
                 raise
 
-            print("Established a connection with the chip")
+            log.print("Established a connection with the chip.")
             if self._esp.secure_download_mode and not secure_download_mode_before:
-                print("Secure download mode is enabled")
+                log.print("Secure download mode is enabled.")
                 if not self["ENABLE_SECURITY_DOWNLOAD"].get() and self[
                     "ENABLE_SECURITY_DOWNLOAD"
                 ].get(from_read=False):
-                    print(
-                        "espefuse tool can not continue to work in Secure download mode"
+                    log.print(
+                        "espefuse can not continue to work in Secure download mode."
                     )
-                    print("ENABLE_SECURITY_DOWNLOAD is enabled")
-                    print("Successful")
+                    log.print("ENABLE_SECURITY_DOWNLOAD is enabled.")
+                    log.print("Successful.")
                     sys.exit(0)  # finish without errors
             raise
 
@@ -237,7 +233,7 @@ class EspEfuses(base_fields.EspEfusesBase):
         apb_freq = self.get_crystal_freq()
         if apb_freq != 40:
             raise esptool.FatalError(
-                "The eFuse supports only xtal=40M (xtal was %d)" % apb_freq
+                f"The eFuse supports only xtal=40M (xtal was {apb_freq})."
             )
 
         self.update_reg(self.REGS.EFUSE_DAC_CONF_REG, self.REGS.EFUSE_DAC_NUM_M, 0xFF)
@@ -262,7 +258,7 @@ class EspEfuses(base_fields.EspEfusesBase):
                 ]
                 block.err_bitarray.pos = 0
                 for word in reversed(words):
-                    block.err_bitarray.overwrite(BitArray("uint:32=%d" % word))
+                    block.err_bitarray.overwrite(BitArray(f"uint:32={word}"))
                 block.num_errors = block.err_bitarray.count(True)
                 block.fail = block.num_errors != 0
             else:
@@ -282,9 +278,9 @@ class EspEfuses(base_fields.EspEfusesBase):
 
             ret_fail |= block.fail
             if not silent and (block.fail or block.num_errors):
-                print(
-                    "Error(s) in BLOCK%d [ERRORS:%d FAIL:%d]"
-                    % (block.id, block.num_errors, block.fail)
+                log.print(
+                    f"Error(s) in BLOCK{block.id} "
+                    f"[ERRORS:{block.num_errors} FAIL:{block.fail}]."
                 )
         if (self.debug or ret_fail) and not silent:
             self.print_status_regs()
@@ -316,7 +312,7 @@ class EfuseWafer(EfuseField):
         return (hi_bits << 3) + lo_bits
 
     def save(self, new_value):
-        raise esptool.FatalError("Burning %s is not supported" % self.name)
+        raise esptool.FatalError(f"Burning {self.name} is not supported.")
 
 
 class EfuseTempSensor(EfuseField):
@@ -362,7 +358,7 @@ class EfuseMacField(EfuseField):
     def check(self):
         errs, fail = self.parent.get_block_errors(self.block)
         if errs != 0 or fail:
-            output = "Block%d has ERRORS:%d FAIL:%d" % (self.block, errs, fail)
+            output = f"Block{self.block} has ERRORS:{errs} FAIL:{fail}."
         else:
             output = "OK"
         return "(" + output + ")"
@@ -376,10 +372,8 @@ class EfuseMacField(EfuseField):
 
     def save(self, new_value):
         def print_field(e, new_value):
-            print(
-                "    - '{}' ({}) {} -> {}".format(
-                    e.name, e.description, e.get_bitstring(), new_value
-                )
+            log.print(
+                f"    - '{e.name}' ({e.description}) {e.get_bitstring()} -> {new_value}"
             )
 
         if self.name == "CUSTOM_MAC":
@@ -420,9 +414,9 @@ class EfuseKeyPurposeField(EfuseField):
                 break
         if raw_val.isdigit():
             if int(raw_val) not in [p[1] for p in self.KEY_PURPOSES if p[1] > 0]:
-                raise esptool.FatalError("'%s' can not be set (value out of range)" % raw_val)
+                raise esptool.FatalError(f"'{raw_val}' can not be set (value out of range)")
         else:
-            raise esptool.FatalError("'%s' unknown name" % raw_val)
+            raise esptool.FatalError(f"'{raw_val}' unknown name")
         return raw_val
 
     def need_reverse(self, new_key_purpose):
